@@ -30,8 +30,8 @@ def export_avatar(
 
     # set up task params
     params = {
-        body_sizes,
-        work_path
+        'body_sizes': body_sizes,
+        'work_path': work_path
     }
     data = json.dumps(params)
 
